Welcome to Ladybug Comfort's documentation!
===================================

.. image:: http://www.ladybug.tools/assets/img/ladybug.png

Ladybug-comfort is a Python library that adds thermal comfort functionalities to
`ladybug-core <https://github.com/ladybug-tools/ladybug/>`_.

Installation
============

``pip install -U ladybug-comfort``


.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. include:: modules.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
